# This file was automatically generated by SWIG (https://www.swig.org).
# Version 4.3.1
#
# Do not make changes to this file unless you know what you are doing - modify
# the SWIG interface file instead.


import collections

from sys import version_info as _version_info
if _version_info < (3, 7, 0):
    raise RuntimeError("Python 3.7 or later required")

from . import _ITKCommonPython


from . import _ITKNarrowBandPython



from sys import version_info as _swig_python_version_info
# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _ITKNarrowBandBasePython
else:
    import _ITKNarrowBandBasePython

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "this":
            set(self, name, value)
        elif name == "thisown":
            self.this.own(value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


if _swig_python_version_info[0:2] >= (3, 3):
    import collections.abc
else:
    import collections

import itk.ITKCommonBasePython
import itk.itkMatrixPython
import itk.itkVectorPython
import itk.vnl_vectorPython
import itk.stdcomplexPython
import itk.pyBasePython
import itk.vnl_matrixPython
import itk.vnl_vector_refPython
import itk.itkFixedArrayPython
import itk.itkCovariantVectorPython
import itk.itkPointPython
import itk.vnl_matrix_fixedPython
class itkBandNodeI2F(object):
    r"""Proxy of C++ itkBandNodeI2F class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr
    __swig_destroy__ = _ITKNarrowBandBasePython.delete_itkBandNodeI2F

    def __init__(self, *args):
        r"""
        __init__(self) -> itkBandNodeI2F
        __init__(self, arg0) -> itkBandNodeI2F

        Parameters
        ----------
        arg0: itkBandNodeI2F const &

        """
        _ITKNarrowBandBasePython.itkBandNodeI2F_swiginit(self, _ITKNarrowBandBasePython.new_itkBandNodeI2F(*args))

# Register itkBandNodeI2F in _ITKNarrowBandBasePython:
_ITKNarrowBandBasePython.itkBandNodeI2F_swigregister(itkBandNodeI2F)
class itkBandNodeI2SS(object):
    r"""Proxy of C++ itkBandNodeI2SS class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr
    __swig_destroy__ = _ITKNarrowBandBasePython.delete_itkBandNodeI2SS

    def __init__(self, *args):
        r"""
        __init__(self) -> itkBandNodeI2SS
        __init__(self, arg0) -> itkBandNodeI2SS

        Parameters
        ----------
        arg0: itkBandNodeI2SS const &

        """
        _ITKNarrowBandBasePython.itkBandNodeI2SS_swiginit(self, _ITKNarrowBandBasePython.new_itkBandNodeI2SS(*args))

# Register itkBandNodeI2SS in _ITKNarrowBandBasePython:
_ITKNarrowBandBasePython.itkBandNodeI2SS_swigregister(itkBandNodeI2SS)
class itkBandNodeI2UC(object):
    r"""Proxy of C++ itkBandNodeI2UC class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr
    __swig_destroy__ = _ITKNarrowBandBasePython.delete_itkBandNodeI2UC

    def __init__(self, *args):
        r"""
        __init__(self) -> itkBandNodeI2UC
        __init__(self, arg0) -> itkBandNodeI2UC

        Parameters
        ----------
        arg0: itkBandNodeI2UC const &

        """
        _ITKNarrowBandBasePython.itkBandNodeI2UC_swiginit(self, _ITKNarrowBandBasePython.new_itkBandNodeI2UC(*args))

# Register itkBandNodeI2UC in _ITKNarrowBandBasePython:
_ITKNarrowBandBasePython.itkBandNodeI2UC_swigregister(itkBandNodeI2UC)
class itkBandNodeI3F(object):
    r"""Proxy of C++ itkBandNodeI3F class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr
    __swig_destroy__ = _ITKNarrowBandBasePython.delete_itkBandNodeI3F

    def __init__(self, *args):
        r"""
        __init__(self) -> itkBandNodeI3F
        __init__(self, arg0) -> itkBandNodeI3F

        Parameters
        ----------
        arg0: itkBandNodeI3F const &

        """
        _ITKNarrowBandBasePython.itkBandNodeI3F_swiginit(self, _ITKNarrowBandBasePython.new_itkBandNodeI3F(*args))

# Register itkBandNodeI3F in _ITKNarrowBandBasePython:
_ITKNarrowBandBasePython.itkBandNodeI3F_swigregister(itkBandNodeI3F)
class itkBandNodeI3SS(object):
    r"""Proxy of C++ itkBandNodeI3SS class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr
    __swig_destroy__ = _ITKNarrowBandBasePython.delete_itkBandNodeI3SS

    def __init__(self, *args):
        r"""
        __init__(self) -> itkBandNodeI3SS
        __init__(self, arg0) -> itkBandNodeI3SS

        Parameters
        ----------
        arg0: itkBandNodeI3SS const &

        """
        _ITKNarrowBandBasePython.itkBandNodeI3SS_swiginit(self, _ITKNarrowBandBasePython.new_itkBandNodeI3SS(*args))

# Register itkBandNodeI3SS in _ITKNarrowBandBasePython:
_ITKNarrowBandBasePython.itkBandNodeI3SS_swigregister(itkBandNodeI3SS)
class itkBandNodeI3UC(object):
    r"""Proxy of C++ itkBandNodeI3UC class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr
    __swig_destroy__ = _ITKNarrowBandBasePython.delete_itkBandNodeI3UC

    def __init__(self, *args):
        r"""
        __init__(self) -> itkBandNodeI3UC
        __init__(self, arg0) -> itkBandNodeI3UC

        Parameters
        ----------
        arg0: itkBandNodeI3UC const &

        """
        _ITKNarrowBandBasePython.itkBandNodeI3UC_swiginit(self, _ITKNarrowBandBasePython.new_itkBandNodeI3UC(*args))

# Register itkBandNodeI3UC in _ITKNarrowBandBasePython:
_ITKNarrowBandBasePython.itkBandNodeI3UC_swigregister(itkBandNodeI3UC)

def itkNarrowBandBNI2F_New():
    return itkNarrowBandBNI2F.New()

class itkNarrowBandBNI2F(itk.ITKCommonBasePython.itkLightObject):
    r"""Proxy of C++ itkNarrowBandBNI2F class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkNarrowBandBNI2F_Pointer"""
        return _ITKNarrowBandBasePython.itkNarrowBandBNI2F___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkNarrowBandBNI2F_Pointer"""
        return _ITKNarrowBandBasePython.itkNarrowBandBNI2F_Clone(self)

    def Size(self):
        r"""Size(self) -> unsigned long"""
        return _ITKNarrowBandBasePython.itkNarrowBandBNI2F_Size(self)

    def Empty(self):
        r"""Empty(self) -> bool"""
        return _ITKNarrowBandBasePython.itkNarrowBandBNI2F_Empty(self)

    def Clear(self):
        r"""Clear(self)"""
        return _ITKNarrowBandBasePython.itkNarrowBandBNI2F_Clear(self)

    def Reserve(self, n):
        r"""
        Reserve(self, n)

        Parameters
        ----------
        n: unsigned long

        """
        return _ITKNarrowBandBasePython.itkNarrowBandBNI2F_Reserve(self, n)

    def PushBack(self, n):
        r"""
        PushBack(self, n)

        Parameters
        ----------
        n: itkBandNodeI2F const &

        """
        return _ITKNarrowBandBasePython.itkNarrowBandBNI2F_PushBack(self, n)

    def PopBack(self):
        r"""PopBack(self)"""
        return _ITKNarrowBandBasePython.itkNarrowBandBNI2F_PopBack(self)

    def Resize(self, n):
        r"""
        Resize(self, n)

        Parameters
        ----------
        n: unsigned long

        """
        return _ITKNarrowBandBasePython.itkNarrowBandBNI2F_Resize(self, n)

    def SetTotalRadius(self, val):
        r"""
        SetTotalRadius(self, val)

        Parameters
        ----------
        val: float const

        """
        return _ITKNarrowBandBasePython.itkNarrowBandBNI2F_SetTotalRadius(self, val)

    def GetTotalRadius(self):
        r"""GetTotalRadius(self) -> float"""
        return _ITKNarrowBandBasePython.itkNarrowBandBNI2F_GetTotalRadius(self)

    def SetInnerRadius(self, val):
        r"""
        SetInnerRadius(self, val)

        Parameters
        ----------
        val: float const

        """
        return _ITKNarrowBandBasePython.itkNarrowBandBNI2F_SetInnerRadius(self, val)

    def GetInnerRadius(self):
        r"""GetInnerRadius(self) -> float"""
        return _ITKNarrowBandBasePython.itkNarrowBandBNI2F_GetInnerRadius(self)
    __swig_destroy__ = _ITKNarrowBandBasePython.delete_itkNarrowBandBNI2F

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkNarrowBandBNI2F

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _ITKNarrowBandBasePython.itkNarrowBandBNI2F_cast(obj)

    def New(*args, **kargs):
        """New() -> itkNarrowBandBNI2F

        Create a new object of the class itkNarrowBandBNI2F and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkNarrowBandBNI2F.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkNarrowBandBNI2F.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkNarrowBandBNI2F.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkNarrowBandBNI2F in _ITKNarrowBandBasePython:
_ITKNarrowBandBasePython.itkNarrowBandBNI2F_swigregister(itkNarrowBandBNI2F)

def itkNarrowBandBNI2SS_New():
    return itkNarrowBandBNI2SS.New()

class itkNarrowBandBNI2SS(itk.ITKCommonBasePython.itkLightObject):
    r"""Proxy of C++ itkNarrowBandBNI2SS class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkNarrowBandBNI2SS_Pointer"""
        return _ITKNarrowBandBasePython.itkNarrowBandBNI2SS___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkNarrowBandBNI2SS_Pointer"""
        return _ITKNarrowBandBasePython.itkNarrowBandBNI2SS_Clone(self)

    def Size(self):
        r"""Size(self) -> unsigned long"""
        return _ITKNarrowBandBasePython.itkNarrowBandBNI2SS_Size(self)

    def Empty(self):
        r"""Empty(self) -> bool"""
        return _ITKNarrowBandBasePython.itkNarrowBandBNI2SS_Empty(self)

    def Clear(self):
        r"""Clear(self)"""
        return _ITKNarrowBandBasePython.itkNarrowBandBNI2SS_Clear(self)

    def Reserve(self, n):
        r"""
        Reserve(self, n)

        Parameters
        ----------
        n: unsigned long

        """
        return _ITKNarrowBandBasePython.itkNarrowBandBNI2SS_Reserve(self, n)

    def PushBack(self, n):
        r"""
        PushBack(self, n)

        Parameters
        ----------
        n: itkBandNodeI2SS const &

        """
        return _ITKNarrowBandBasePython.itkNarrowBandBNI2SS_PushBack(self, n)

    def PopBack(self):
        r"""PopBack(self)"""
        return _ITKNarrowBandBasePython.itkNarrowBandBNI2SS_PopBack(self)

    def Resize(self, n):
        r"""
        Resize(self, n)

        Parameters
        ----------
        n: unsigned long

        """
        return _ITKNarrowBandBasePython.itkNarrowBandBNI2SS_Resize(self, n)

    def SetTotalRadius(self, val):
        r"""
        SetTotalRadius(self, val)

        Parameters
        ----------
        val: float const

        """
        return _ITKNarrowBandBasePython.itkNarrowBandBNI2SS_SetTotalRadius(self, val)

    def GetTotalRadius(self):
        r"""GetTotalRadius(self) -> float"""
        return _ITKNarrowBandBasePython.itkNarrowBandBNI2SS_GetTotalRadius(self)

    def SetInnerRadius(self, val):
        r"""
        SetInnerRadius(self, val)

        Parameters
        ----------
        val: float const

        """
        return _ITKNarrowBandBasePython.itkNarrowBandBNI2SS_SetInnerRadius(self, val)

    def GetInnerRadius(self):
        r"""GetInnerRadius(self) -> float"""
        return _ITKNarrowBandBasePython.itkNarrowBandBNI2SS_GetInnerRadius(self)
    __swig_destroy__ = _ITKNarrowBandBasePython.delete_itkNarrowBandBNI2SS

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkNarrowBandBNI2SS

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _ITKNarrowBandBasePython.itkNarrowBandBNI2SS_cast(obj)

    def New(*args, **kargs):
        """New() -> itkNarrowBandBNI2SS

        Create a new object of the class itkNarrowBandBNI2SS and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkNarrowBandBNI2SS.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkNarrowBandBNI2SS.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkNarrowBandBNI2SS.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkNarrowBandBNI2SS in _ITKNarrowBandBasePython:
_ITKNarrowBandBasePython.itkNarrowBandBNI2SS_swigregister(itkNarrowBandBNI2SS)

def itkNarrowBandBNI2UC_New():
    return itkNarrowBandBNI2UC.New()

class itkNarrowBandBNI2UC(itk.ITKCommonBasePython.itkLightObject):
    r"""Proxy of C++ itkNarrowBandBNI2UC class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkNarrowBandBNI2UC_Pointer"""
        return _ITKNarrowBandBasePython.itkNarrowBandBNI2UC___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkNarrowBandBNI2UC_Pointer"""
        return _ITKNarrowBandBasePython.itkNarrowBandBNI2UC_Clone(self)

    def Size(self):
        r"""Size(self) -> unsigned long"""
        return _ITKNarrowBandBasePython.itkNarrowBandBNI2UC_Size(self)

    def Empty(self):
        r"""Empty(self) -> bool"""
        return _ITKNarrowBandBasePython.itkNarrowBandBNI2UC_Empty(self)

    def Clear(self):
        r"""Clear(self)"""
        return _ITKNarrowBandBasePython.itkNarrowBandBNI2UC_Clear(self)

    def Reserve(self, n):
        r"""
        Reserve(self, n)

        Parameters
        ----------
        n: unsigned long

        """
        return _ITKNarrowBandBasePython.itkNarrowBandBNI2UC_Reserve(self, n)

    def PushBack(self, n):
        r"""
        PushBack(self, n)

        Parameters
        ----------
        n: itkBandNodeI2UC const &

        """
        return _ITKNarrowBandBasePython.itkNarrowBandBNI2UC_PushBack(self, n)

    def PopBack(self):
        r"""PopBack(self)"""
        return _ITKNarrowBandBasePython.itkNarrowBandBNI2UC_PopBack(self)

    def Resize(self, n):
        r"""
        Resize(self, n)

        Parameters
        ----------
        n: unsigned long

        """
        return _ITKNarrowBandBasePython.itkNarrowBandBNI2UC_Resize(self, n)

    def SetTotalRadius(self, val):
        r"""
        SetTotalRadius(self, val)

        Parameters
        ----------
        val: float const

        """
        return _ITKNarrowBandBasePython.itkNarrowBandBNI2UC_SetTotalRadius(self, val)

    def GetTotalRadius(self):
        r"""GetTotalRadius(self) -> float"""
        return _ITKNarrowBandBasePython.itkNarrowBandBNI2UC_GetTotalRadius(self)

    def SetInnerRadius(self, val):
        r"""
        SetInnerRadius(self, val)

        Parameters
        ----------
        val: float const

        """
        return _ITKNarrowBandBasePython.itkNarrowBandBNI2UC_SetInnerRadius(self, val)

    def GetInnerRadius(self):
        r"""GetInnerRadius(self) -> float"""
        return _ITKNarrowBandBasePython.itkNarrowBandBNI2UC_GetInnerRadius(self)
    __swig_destroy__ = _ITKNarrowBandBasePython.delete_itkNarrowBandBNI2UC

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkNarrowBandBNI2UC

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _ITKNarrowBandBasePython.itkNarrowBandBNI2UC_cast(obj)

    def New(*args, **kargs):
        """New() -> itkNarrowBandBNI2UC

        Create a new object of the class itkNarrowBandBNI2UC and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkNarrowBandBNI2UC.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkNarrowBandBNI2UC.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkNarrowBandBNI2UC.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkNarrowBandBNI2UC in _ITKNarrowBandBasePython:
_ITKNarrowBandBasePython.itkNarrowBandBNI2UC_swigregister(itkNarrowBandBNI2UC)

def itkNarrowBandBNI3F_New():
    return itkNarrowBandBNI3F.New()

class itkNarrowBandBNI3F(itk.ITKCommonBasePython.itkLightObject):
    r"""Proxy of C++ itkNarrowBandBNI3F class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkNarrowBandBNI3F_Pointer"""
        return _ITKNarrowBandBasePython.itkNarrowBandBNI3F___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkNarrowBandBNI3F_Pointer"""
        return _ITKNarrowBandBasePython.itkNarrowBandBNI3F_Clone(self)

    def Size(self):
        r"""Size(self) -> unsigned long"""
        return _ITKNarrowBandBasePython.itkNarrowBandBNI3F_Size(self)

    def Empty(self):
        r"""Empty(self) -> bool"""
        return _ITKNarrowBandBasePython.itkNarrowBandBNI3F_Empty(self)

    def Clear(self):
        r"""Clear(self)"""
        return _ITKNarrowBandBasePython.itkNarrowBandBNI3F_Clear(self)

    def Reserve(self, n):
        r"""
        Reserve(self, n)

        Parameters
        ----------
        n: unsigned long

        """
        return _ITKNarrowBandBasePython.itkNarrowBandBNI3F_Reserve(self, n)

    def PushBack(self, n):
        r"""
        PushBack(self, n)

        Parameters
        ----------
        n: itkBandNodeI3F const &

        """
        return _ITKNarrowBandBasePython.itkNarrowBandBNI3F_PushBack(self, n)

    def PopBack(self):
        r"""PopBack(self)"""
        return _ITKNarrowBandBasePython.itkNarrowBandBNI3F_PopBack(self)

    def Resize(self, n):
        r"""
        Resize(self, n)

        Parameters
        ----------
        n: unsigned long

        """
        return _ITKNarrowBandBasePython.itkNarrowBandBNI3F_Resize(self, n)

    def SetTotalRadius(self, val):
        r"""
        SetTotalRadius(self, val)

        Parameters
        ----------
        val: float const

        """
        return _ITKNarrowBandBasePython.itkNarrowBandBNI3F_SetTotalRadius(self, val)

    def GetTotalRadius(self):
        r"""GetTotalRadius(self) -> float"""
        return _ITKNarrowBandBasePython.itkNarrowBandBNI3F_GetTotalRadius(self)

    def SetInnerRadius(self, val):
        r"""
        SetInnerRadius(self, val)

        Parameters
        ----------
        val: float const

        """
        return _ITKNarrowBandBasePython.itkNarrowBandBNI3F_SetInnerRadius(self, val)

    def GetInnerRadius(self):
        r"""GetInnerRadius(self) -> float"""
        return _ITKNarrowBandBasePython.itkNarrowBandBNI3F_GetInnerRadius(self)
    __swig_destroy__ = _ITKNarrowBandBasePython.delete_itkNarrowBandBNI3F

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkNarrowBandBNI3F

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _ITKNarrowBandBasePython.itkNarrowBandBNI3F_cast(obj)

    def New(*args, **kargs):
        """New() -> itkNarrowBandBNI3F

        Create a new object of the class itkNarrowBandBNI3F and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkNarrowBandBNI3F.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkNarrowBandBNI3F.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkNarrowBandBNI3F.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkNarrowBandBNI3F in _ITKNarrowBandBasePython:
_ITKNarrowBandBasePython.itkNarrowBandBNI3F_swigregister(itkNarrowBandBNI3F)

def itkNarrowBandBNI3SS_New():
    return itkNarrowBandBNI3SS.New()

class itkNarrowBandBNI3SS(itk.ITKCommonBasePython.itkLightObject):
    r"""Proxy of C++ itkNarrowBandBNI3SS class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkNarrowBandBNI3SS_Pointer"""
        return _ITKNarrowBandBasePython.itkNarrowBandBNI3SS___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkNarrowBandBNI3SS_Pointer"""
        return _ITKNarrowBandBasePython.itkNarrowBandBNI3SS_Clone(self)

    def Size(self):
        r"""Size(self) -> unsigned long"""
        return _ITKNarrowBandBasePython.itkNarrowBandBNI3SS_Size(self)

    def Empty(self):
        r"""Empty(self) -> bool"""
        return _ITKNarrowBandBasePython.itkNarrowBandBNI3SS_Empty(self)

    def Clear(self):
        r"""Clear(self)"""
        return _ITKNarrowBandBasePython.itkNarrowBandBNI3SS_Clear(self)

    def Reserve(self, n):
        r"""
        Reserve(self, n)

        Parameters
        ----------
        n: unsigned long

        """
        return _ITKNarrowBandBasePython.itkNarrowBandBNI3SS_Reserve(self, n)

    def PushBack(self, n):
        r"""
        PushBack(self, n)

        Parameters
        ----------
        n: itkBandNodeI3SS const &

        """
        return _ITKNarrowBandBasePython.itkNarrowBandBNI3SS_PushBack(self, n)

    def PopBack(self):
        r"""PopBack(self)"""
        return _ITKNarrowBandBasePython.itkNarrowBandBNI3SS_PopBack(self)

    def Resize(self, n):
        r"""
        Resize(self, n)

        Parameters
        ----------
        n: unsigned long

        """
        return _ITKNarrowBandBasePython.itkNarrowBandBNI3SS_Resize(self, n)

    def SetTotalRadius(self, val):
        r"""
        SetTotalRadius(self, val)

        Parameters
        ----------
        val: float const

        """
        return _ITKNarrowBandBasePython.itkNarrowBandBNI3SS_SetTotalRadius(self, val)

    def GetTotalRadius(self):
        r"""GetTotalRadius(self) -> float"""
        return _ITKNarrowBandBasePython.itkNarrowBandBNI3SS_GetTotalRadius(self)

    def SetInnerRadius(self, val):
        r"""
        SetInnerRadius(self, val)

        Parameters
        ----------
        val: float const

        """
        return _ITKNarrowBandBasePython.itkNarrowBandBNI3SS_SetInnerRadius(self, val)

    def GetInnerRadius(self):
        r"""GetInnerRadius(self) -> float"""
        return _ITKNarrowBandBasePython.itkNarrowBandBNI3SS_GetInnerRadius(self)
    __swig_destroy__ = _ITKNarrowBandBasePython.delete_itkNarrowBandBNI3SS

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkNarrowBandBNI3SS

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _ITKNarrowBandBasePython.itkNarrowBandBNI3SS_cast(obj)

    def New(*args, **kargs):
        """New() -> itkNarrowBandBNI3SS

        Create a new object of the class itkNarrowBandBNI3SS and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkNarrowBandBNI3SS.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkNarrowBandBNI3SS.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkNarrowBandBNI3SS.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkNarrowBandBNI3SS in _ITKNarrowBandBasePython:
_ITKNarrowBandBasePython.itkNarrowBandBNI3SS_swigregister(itkNarrowBandBNI3SS)

def itkNarrowBandBNI3UC_New():
    return itkNarrowBandBNI3UC.New()

class itkNarrowBandBNI3UC(itk.ITKCommonBasePython.itkLightObject):
    r"""Proxy of C++ itkNarrowBandBNI3UC class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkNarrowBandBNI3UC_Pointer"""
        return _ITKNarrowBandBasePython.itkNarrowBandBNI3UC___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkNarrowBandBNI3UC_Pointer"""
        return _ITKNarrowBandBasePython.itkNarrowBandBNI3UC_Clone(self)

    def Size(self):
        r"""Size(self) -> unsigned long"""
        return _ITKNarrowBandBasePython.itkNarrowBandBNI3UC_Size(self)

    def Empty(self):
        r"""Empty(self) -> bool"""
        return _ITKNarrowBandBasePython.itkNarrowBandBNI3UC_Empty(self)

    def Clear(self):
        r"""Clear(self)"""
        return _ITKNarrowBandBasePython.itkNarrowBandBNI3UC_Clear(self)

    def Reserve(self, n):
        r"""
        Reserve(self, n)

        Parameters
        ----------
        n: unsigned long

        """
        return _ITKNarrowBandBasePython.itkNarrowBandBNI3UC_Reserve(self, n)

    def PushBack(self, n):
        r"""
        PushBack(self, n)

        Parameters
        ----------
        n: itkBandNodeI3UC const &

        """
        return _ITKNarrowBandBasePython.itkNarrowBandBNI3UC_PushBack(self, n)

    def PopBack(self):
        r"""PopBack(self)"""
        return _ITKNarrowBandBasePython.itkNarrowBandBNI3UC_PopBack(self)

    def Resize(self, n):
        r"""
        Resize(self, n)

        Parameters
        ----------
        n: unsigned long

        """
        return _ITKNarrowBandBasePython.itkNarrowBandBNI3UC_Resize(self, n)

    def SetTotalRadius(self, val):
        r"""
        SetTotalRadius(self, val)

        Parameters
        ----------
        val: float const

        """
        return _ITKNarrowBandBasePython.itkNarrowBandBNI3UC_SetTotalRadius(self, val)

    def GetTotalRadius(self):
        r"""GetTotalRadius(self) -> float"""
        return _ITKNarrowBandBasePython.itkNarrowBandBNI3UC_GetTotalRadius(self)

    def SetInnerRadius(self, val):
        r"""
        SetInnerRadius(self, val)

        Parameters
        ----------
        val: float const

        """
        return _ITKNarrowBandBasePython.itkNarrowBandBNI3UC_SetInnerRadius(self, val)

    def GetInnerRadius(self):
        r"""GetInnerRadius(self) -> float"""
        return _ITKNarrowBandBasePython.itkNarrowBandBNI3UC_GetInnerRadius(self)
    __swig_destroy__ = _ITKNarrowBandBasePython.delete_itkNarrowBandBNI3UC

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkNarrowBandBNI3UC

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _ITKNarrowBandBasePython.itkNarrowBandBNI3UC_cast(obj)

    def New(*args, **kargs):
        """New() -> itkNarrowBandBNI3UC

        Create a new object of the class itkNarrowBandBNI3UC and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkNarrowBandBNI3UC.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkNarrowBandBNI3UC.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkNarrowBandBNI3UC.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkNarrowBandBNI3UC in _ITKNarrowBandBasePython:
_ITKNarrowBandBasePython.itkNarrowBandBNI3UC_swigregister(itkNarrowBandBNI3UC)

